==> openshift-model-5.1.0-sources.jar: io/fabric8/openshift/api/model/ScopeRestrictionFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class ScopeRestrictionFluentImpl<A extends ScopeRestrictionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ScopeRestrictionFluent<A> {

    private ClusterRoleScopeRestrictionBuilder clusterRole;
    private List<String> literals = new ArrayList<String>();

    public ScopeRestrictionFluentImpl() {
    }

    public ScopeRestrictionFluentImpl(ScopeRestriction instance) {
        this.withClusterRole(instance.getClusterRole()); 
        this.withLiterals(instance.getLiterals()); 
    }

    
/**
 * This method has been deprecated, please use method buildClusterRole instead.
 * @return The buildable object.
 */
@Deprecated public ClusterRoleScopeRestriction getClusterRole() {
        return this.clusterRole!=null?this.clusterRole.build():null;
    }

    public ClusterRoleScopeRestriction buildClusterRole() {
        return this.clusterRole!=null?this.clusterRole.build():null;
    }

    public A withClusterRole(ClusterRoleScopeRestriction clusterRole) {
        _visitables.get("clusterRole").remove(this.clusterRole);
        if (clusterRole!=null){ this.clusterRole= new ClusterRoleScopeRestrictionBuilder(clusterRole); _visitables.get("clusterRole").add(this.clusterRole);} return (A) this;
    }

    public Boolean hasClusterRole() {
        return this.clusterRole != null;
    }

    public ScopeRestrictionFluent.ClusterRoleNested<A> withNewClusterRole() {
        return new ClusterRoleNestedImpl();
    }

    public ScopeRestrictionFluent.ClusterRoleNested<A> withNewClusterRoleLike(ClusterRoleScopeRestriction item) {
        return new ClusterRoleNestedImpl(item);
    }

    public ScopeRestrictionFluent.ClusterRoleNested<A> editClusterRole() {
        return withNewClusterRoleLike(getClusterRole());
    }

    public ScopeRestrictionFluent.ClusterRoleNested<A> editOrNewClusterRole() {
        return withNewClusterRoleLike(getClusterRole() != null ? getClusterRole(): new ClusterRoleScopeRestrictionBuilder().build());
    }

    public ScopeRestrictionFluent.ClusterRoleNested<A> editOrNewClusterRoleLike(ClusterRoleScopeRestriction item) {
        return withNewClusterRoleLike(getClusterRole() != null ? getClusterRole(): item);
    }

    public A addToLiterals(int index,String item) {
        if (this.literals == null) {this.literals = new ArrayList<String>();}
        this.literals.add(index, item);
        return (A)this;
    }

    public A setToLiterals(int index,String item) {
        if (this.literals == null) {this.literals = new ArrayList<String>();}
        this.literals.set(index, item); return (A)this;
    }

    public A addToLiterals(String... items) {
        if (this.literals == null) {this.literals = new ArrayList<String>();}
        for (String item : items) {this.literals.add(item);} return (A)this;
    }

    public A addAllToLiterals(Collection<String> items) {
        if (this.literals == null) {this.literals = new ArrayList<String>();}
        for (String item : items) {this.literals.add(item);} return (A)this;
    }

    public A removeFromLiterals(String... items) {
        for (String item : items) {if (this.literals!= null){ this.literals.remove(item);}} return (A)this;
    }

    public A removeAllFromLiterals(Collection<String> items) {
        for (String item : items) {if (this.literals!= null){ this.literals.remove(item);}} return (A)this;
    }

    public List<String> getLiterals() {
        return this.literals;
    }

    public String getLiteral(int index) {
        return this.literals.get(index);
    }

    public String getFirstLiteral() {
        return this.literals.get(0);
    }

    public String getLastLiteral() {
        return this.literals.get(literals.size() - 1);
    }

    public String getMatchingLiteral(Predicate<String> predicate) {
        for (String item: literals) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingLiteral(Predicate<String> predicate) {
        for (String item: literals) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withLiterals(List<String> literals) {
        if (this.literals != null) { _visitables.get("literals").removeAll(this.literals);}
        if (literals != null) {this.literals = new ArrayList<String>(); for (String item : literals){this.addToLiterals(item);}} else { this.literals = null;} return (A) this;
    }

    public A withLiterals(String... literals) {
        if (this.literals != null) {this.literals.clear();}
        if (literals != null) {for (String item :literals){ this.addToLiterals(item);}} return (A) this;
    }

    public Boolean hasLiterals() {
        return literals != null && !literals.isEmpty();
    }

    public A addNewLiteral(String arg1) {
        return (A)addToLiterals(new String(arg1));
    }

    public A addNewLiteral(StringBuilder arg1) {
        return (A)addToLiterals(new String(arg1));
    }

    public A addNewLiteral(StringBuffer arg1) {
        return (A)addToLiterals(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ScopeRestrictionFluentImpl that = (ScopeRestrictionFluentImpl) o;
        if (clusterRole != null ? !clusterRole.equals(that.clusterRole) :that.clusterRole != null) return false;
        if (literals != null ? !literals.equals(that.literals) :that.literals != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(clusterRole,  literals,  super.hashCode());
    }

    public class ClusterRoleNestedImpl<N> extends ClusterRoleScopeRestrictionFluentImpl<ScopeRestrictionFluent.ClusterRoleNested<N>> implements ScopeRestrictionFluent.ClusterRoleNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ClusterRoleScopeRestrictionBuilder builder;

            ClusterRoleNestedImpl(ClusterRoleScopeRestriction item) {
                this.builder = new ClusterRoleScopeRestrictionBuilder(this, item);
                        
            }

            ClusterRoleNestedImpl() {
                this.builder = new ClusterRoleScopeRestrictionBuilder(this);
                        
            }

            public N and() {
                return (N) ScopeRestrictionFluentImpl.this.withClusterRole(builder.build());
            }

            public N endClusterRole() {
                return and();
            }
    }


}

==> openshift-model-5.3.2-sources.jar: io/fabric8/openshift/api/model/ScopeRestrictionFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class ScopeRestrictionFluentImpl<A extends ScopeRestrictionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ScopeRestrictionFluent<A> {

    private ClusterRoleScopeRestrictionBuilder clusterRole;
    private List<String> literals = new ArrayList<String>();

    public ScopeRestrictionFluentImpl() {
    }

    public ScopeRestrictionFluentImpl(ScopeRestriction instance) {
        this.withClusterRole(instance.getClusterRole()); 
        this.withLiterals(instance.getLiterals()); 
    }

    
/**
 * This method has been deprecated, please use method buildClusterRole instead.
 * @return The buildable object.
 */
@Deprecated public ClusterRoleScopeRestriction getClusterRole() {
        return this.clusterRole!=null?this.clusterRole.build():null;
    }

    public ClusterRoleScopeRestriction buildClusterRole() {
        return this.clusterRole!=null?this.clusterRole.build():null;
    }

    public A withClusterRole(ClusterRoleScopeRestriction clusterRole) {
        _visitables.get("clusterRole").remove(this.clusterRole);
        if (clusterRole!=null){ this.clusterRole= new ClusterRoleScopeRestrictionBuilder(clusterRole); _visitables.get("clusterRole").add(this.clusterRole);} return (A) this;
    }

    public Boolean hasClusterRole() {
        return this.clusterRole != null;
    }

    public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> withNewClusterRole() {
        return new ClusterRoleNestedImpl();
    }

    public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> withNewClusterRoleLike(ClusterRoleScopeRestriction item) {
        return new ClusterRoleNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> editClusterRole() {
        return withNewClusterRoleLike(getClusterRole());
    }

    public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> editOrNewClusterRole() {
        return withNewClusterRoleLike(getClusterRole() != null ? getClusterRole(): new ClusterRoleScopeRestrictionBuilder().build());
    }

    public io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<A> editOrNewClusterRoleLike(ClusterRoleScopeRestriction item) {
        return withNewClusterRoleLike(getClusterRole() != null ? getClusterRole(): item);
    }

    public A addToLiterals(int index,String item) {
        if (this.literals == null) {this.literals = new ArrayList<String>();}
        this.literals.add(index, item);
        return (A)this;
    }

    public A setToLiterals(int index,String item) {
        if (this.literals == null) {this.literals = new ArrayList<String>();}
        this.literals.set(index, item); return (A)this;
    }

    public A addToLiterals(String... items) {
        if (this.literals == null) {this.literals = new ArrayList<String>();}
        for (String item : items) {this.literals.add(item);} return (A)this;
    }

    public A addAllToLiterals(Collection<String> items) {
        if (this.literals == null) {this.literals = new ArrayList<String>();}
        for (String item : items) {this.literals.add(item);} return (A)this;
    }

    public A removeFromLiterals(String... items) {
        for (String item : items) {if (this.literals!= null){ this.literals.remove(item);}} return (A)this;
    }

    public A removeAllFromLiterals(Collection<String> items) {
        for (String item : items) {if (this.literals!= null){ this.literals.remove(item);}} return (A)this;
    }

    public List<String> getLiterals() {
        return this.literals;
    }

    public String getLiteral(int index) {
        return this.literals.get(index);
    }

    public String getFirstLiteral() {
        return this.literals.get(0);
    }

    public String getLastLiteral() {
        return this.literals.get(literals.size() - 1);
    }

    public String getMatchingLiteral(Predicate<String> predicate) {
        for (String item: literals) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingLiteral(Predicate<String> predicate) {
        for (String item: literals) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withLiterals(List<String> literals) {
        if (this.literals != null) { _visitables.get("literals").removeAll(this.literals);}
        if (literals != null) {this.literals = new ArrayList<String>(); for (String item : literals){this.addToLiterals(item);}} else { this.literals = null;} return (A) this;
    }

    public A withLiterals(String... literals) {
        if (this.literals != null) {this.literals.clear();}
        if (literals != null) {for (String item :literals){ this.addToLiterals(item);}} return (A) this;
    }

    public Boolean hasLiterals() {
        return literals != null && !literals.isEmpty();
    }

    public A addNewLiteral(StringBuilder arg1) {
        return (A)addToLiterals(new String(arg1));
    }

    public A addNewLiteral(int[] arg1,int arg2,int arg3) {
        return (A)addToLiterals(new String(arg1, arg2, arg3));
    }

    public A addNewLiteral(char[] arg1) {
        return (A)addToLiterals(new String(arg1));
    }

    public A addNewLiteral(StringBuffer arg1) {
        return (A)addToLiterals(new String(arg1));
    }

    public A addNewLiteral(byte[] arg1,int arg2) {
        return (A)addToLiterals(new String(arg1, arg2));
    }

    public A addNewLiteral(byte[] arg1) {
        return (A)addToLiterals(new String(arg1));
    }

    public A addNewLiteral(char[] arg1,int arg2,int arg3) {
        return (A)addToLiterals(new String(arg1, arg2, arg3));
    }

    public A addNewLiteral(byte[] arg1,int arg2,int arg3) {
        return (A)addToLiterals(new String(arg1, arg2, arg3));
    }

    public A addNewLiteral(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)addToLiterals(new String(arg1, arg2, arg3, arg4));
    }

    public A addNewLiteral(String arg1) {
        return (A)addToLiterals(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ScopeRestrictionFluentImpl that = (ScopeRestrictionFluentImpl) o;
        if (clusterRole != null ? !clusterRole.equals(that.clusterRole) :that.clusterRole != null) return false;
        if (literals != null ? !literals.equals(that.literals) :that.literals != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(clusterRole,  literals,  super.hashCode());
    }

    public class ClusterRoleNestedImpl<N> extends ClusterRoleScopeRestrictionFluentImpl<io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<N>> implements io.fabric8.openshift.api.model.ScopeRestrictionFluent.ClusterRoleNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ClusterRoleScopeRestrictionBuilder builder;

            ClusterRoleNestedImpl(ClusterRoleScopeRestriction item) {
                this.builder = new ClusterRoleScopeRestrictionBuilder(this, item);
                        
            }

            ClusterRoleNestedImpl() {
                this.builder = new ClusterRoleScopeRestrictionBuilder(this);
                        
            }

            public N and() {
                return (N) ScopeRestrictionFluentImpl.this.withClusterRole(builder.build());
            }

            public N endClusterRole() {
                return and();
            }
    }


}
